An Overview over all Basic Examples
===================================

arrow.bot
---------
Draw a big green arrow.

background.bot
--------------
Draw a big green arrow.

corner_rotate.bot
-----------------
Rotate some text in the upper left corner.

cornu.bot
---------
Play with elegant [cornu curves](http://en.wikipedia.org/wiki/Fresnel_integral) and tweak them with sliders.

ellipse.bot
-----------
Draw an ellipse filled with blue.

fill_stroke.bot
---------------
Draw different rectangles with different strokes and fills.

how_curves_work.bot
-------------------
Demonstrate how the differnet parameters of curves work.

keyboard.bot
------------
Demonstrate some basic keyboard interaction. Try pressing different single keys for differnet durations.

line.bot
--------
Draw a simple line.

mouse.bot
---------
Fill the background of the shoebot windows with a color depending on the mouse cursor position.

path_curveto.bot
----------------
Draw a curve along some points and fill the space enclosed by the path.

path_lineto.bot
---------------
Draw some lines and fill the space enclosed by the path.

primitives.bot
--------------
Draw different primitives (rectangles, arrows and stars) and fill them.

rect.bot
--------
Draw a simple filled rectangle.

star.bot
--------
Draw a simple filled star.

strokewidth.bot
---------------
Draw lines with different stroke widths.

transforms.bot
--------------
Perform some basic transformations (rotation and translation) on rectangles.

var_boolean.bot
---------------
Switch the background color of a window by checking a box.

var_number_hsb.bot
------------------
Play with values in the [HSB](https://en.wikipedia.org/wiki/HSV_color_space) colorspace. Make sure you check the "show" box from time to time.

var_number_rgb.bot
------------------
Play around with values in the [RGB](https://en.wikipedia.org/wiki/RGB_color_model) colorspace.

var_text.bot
------------
Display unicode text and manipulate the font size.
